#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Michael Verret (AxXium)
#last changed		: 02-august-2007

#package			: foobillard
#homepage			: http://foobillard.sunsite.dk/
#source location	: http://foobillard.sunsite.dk/dnl/foobillard-3.0a.tar.gz
#dependencies		: coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib

# ----- credentials
softname="foobillard"
softversion="3.0a"
srcurl="http://foobillard.sunsite.dk/dnl/foobillard-3.0a.tar.gz"
arch=i686
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/share/icons/hicolor/72x72/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
mkdir -p $dest/usr/share/icons/hicolor/192x192/apps
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
          |-----handy-ruler------------------------------------------------------|
foobillard: foobillard (billard game with realistic physics)
foobillard:
foobillard: FooBillard is a free billard game for Linux with realistic
foobillard: physics, AI-player and many gametypes like pool carambol or
foobillard: snooker. There are two supported implementations concerning
foobillard: the interface. A GLUT and an SDL implementation.
foobillard:
foobillard: This package contains the SDL implementation for those
foobillard: systems with modest video cards.
foobillard:
foobillard:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
	--prefix=$prefix \
	--disable-debug
	
# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
cp -a \
	AUTHORS COPYING ChangeLog INSTALL NEWS README README.FONTS TODO \
	$dest/usr/doc/$srcdir

# ----- treat icon-files
cd $builddir
tar -jxvf icons.tar.bz2 --directory=$builddir
mv icon-foobillard-36.png $dest/usr/share/icons/hicolor/36x36/apps/foobillard.png
mv icon-foobillard-48.png $dest/usr/share/icons/hicolor/48x48/apps/foobillard.png
mv icon-foobillard-64.png $dest/usr/share/icons/hicolor/64x64/apps/foobillard.png
mv icon-foobillard-72.png $dest/usr/share/icons/hicolor/72x72/apps/foobillard.png
mv icon-foobillard-128.png $dest/usr/share/icons/hicolor/128x128/apps/foobillard.png
mv icon-foobillard-192.png $dest/usr/share/icons/hicolor/192x192/apps/foobillard.png
cp icons.tar.bz2 $destsrc

# ----- make .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=FooBillard
Comment=Billard game
Exec=foobillard
Icon=foobillard
Terminal=false
Type=Application
Categories=Game;SportsGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
